conditional_cif_b estimates the cumulative incidence function based on the MSM illness-death general Markov model conditional on the fixed random effect b.
conditional_cif_b(res1,
t1_star,
b)The output from em_illness_death_phmm_weight, the general Markov model result.
Fixed non-terminal event time for estimating CIF function for terminal event following the non-terminal event.
Fixed random effect value.
The step function for estimated CIF conditional on b for time to non-terminal event for control group.
The step function for estimated CIF conditional on b for time to non-terminal event for treated group.
The step function for estimated CIF conditional on b for time to terminal event without non-terminal event for control group.
The step function for estimated CIF conditional on b for time to terminal event without non-terminal event for treated group.
The step function for estimated CIF conditional on b for time to terminal event following non-terminal event by t1_start for control group.
The step function for estimated CIF conditional on b for time to terminal event without non-terminal event by t1_start for treated group.
A data frame with time and estimated CIF conditional on b if is treated or controlled for time to non-terminal event.
A data frame with time and estimated CIF conditional on b if is treated or controlled for time to terminal event without non-terminal event.
A data frame with time and estimated CIF conditional on b if is treated or controlled for time to terminal event without non-terminal event by t1_start.
Similar as cif_est_usual, after estimating the parameters in the illness-death model \(\lambda_{j}^a\) using IPW, we could estimate the corresponding conditional CIF under fixed b:
$$ \hat{P}(T_1^a<t,\delta_1^a=1 \mid b) = \int_{0}^{t} \hat{S}^a(u \mid b) d\hat{\Lambda}_{1}^a(u \mid b ), $$
$$ \hat{P}(T_2^a<t,\delta_1^a=0,\delta_2^a=1 \mid b) = \int_{0}^{t} \hat{S}^a(u \mid b) d\hat{\Lambda}_{2}^a(u \mid b), $$
and
$$ \hat{P}(T_2^a<t_2 \mid T_1^a<t_1, T_2^a>t_1 \mid b) = 1- e^{- \int_{t_1}^{t_2} d \hat{\Lambda}_{12}^a(u \mid b) }, $$
where \(\hat{S}^a\) is the estimated overall survial function for joint \(T_1^a, T_2^a\), \( \hat{S}^a(u) = e^{-\hat{\Lambda}_{1}^a(u)} - \hat{\Lambda}_{2}^a(u) \). We obtain three hazards by fitting the MSM illness-death model \( \hat\Lambda_{j}^a(u) = \hat\Lambda_{0j}(u)e^{\hat\beta_j*a} \), \( \hat\Lambda_{12}^a(u) = \hat\Lambda_{03}(u)e^{\hat\beta_3*a} \), and \( \hat\Lambda_{0j}(u) \) is a Breslow-type estimator of the baseline cumulative hazard.
where \( S(t \mid b;a) = \exp[- \int_0^{t} \{ \lambda_{01} (u)e^{\beta_1a + b} + \lambda_{02} (u )e^{\beta_2a + b} \} d u ] = \exp \{- e^{\beta_1a + b} \Lambda_{01}(t) - e^{\beta_2a + b} \Lambda_{02} (t ) \} \)
cif_est_usual