powered by
Compute the Breslow type baseline hazard and cumulative baseline hazard at each event time from a Cox model.
get_hazard(fit)
The results of a coxph fit.
coxph
A list contains two dataframes.
See also basehaz, returns the Breslow type cumulative baseline hazard.
basehaz
Returns the Breslow type baseline hazard.
See also basehaz, we only extract the estimated baseline hazard and baseline cumulative hazard from the results of a coxph fit.