Compute the Breslow type baseline hazard and cumulative baseline hazard at each event time from a weighted Cox model with offsets.
get_hazard_offset_weights(fit,data,time1= NULL,time2,w)The results of a weighted coxph fit.
The original data for fitting the weighted Cox model.
The default is NULL. For left truncation data, which refers to transition rate for terminal event following non-terminal events, this argument is the time to non-terminal event.
For right censored data, this is the event time or censoring time. For left truncation data, the argument is the time to terminal event or the censoring time.
IP weights.
A list contains two dataframes.
See also get_hazard, returns a step function for cumulative baseline hazard.
Returns a dataframe for baseline hazard.
Returns a dataframe for cumulative baseline hazard.
See also get_hazard, handles the offset term in coxph for predicting the baseline hazard.
get_hazard, basehaz