Fit the MSM cox model with IPW as the initial value for EM algorithm to fit the illness-death general Markov model
initial_fit_em_weights(data,X1,X2,event1,event2,w,Trt)The dataset, includes non-terminal events, terminal events as well as event indicator.
Time to non-terminal event, could be censored by terminal event or lost to follow up.
Time to terminal event, could be censored by lost to follow up.
Event indicator for non-terminal event.
Event indicator for terminal event.
IP weights.
Treatment variable.
A list of objects from survival package:
An object of class Surv for non-terminal event.
An object of class Surv for terminal event without non-terminal event.
An object of class Surv for terminal event following non-terminal event.
An object of class coxph representing the fit for time to non-terminal event. See coxph.object for details.
An object of class coxph representing the fit for time to terminal event without non-terminal event.
An object of class coxph representing the fit for time to terminal event following non-terminal event.
As initial values we use for \(\beta_j\), \(j=1, 2, 3\), the estimates from IP weighted Cox regression without the offsets, i.e. from the usual Markov model.
Surv, coxph