Use bootstrap to obtain the variance estimator for parameters in MSM illness-death general markov model.
var_em_illness_death_phmm(data,sigma_2_0,VARS.)The output dataset from em_illness_death_phmm_weight.
Initial value for \(\sigma^2\), the variance of zero-mean normal frailty, usually starts with 1.
Confounder sets.
List of bootstrap SE for all the parameters in the general Markov model
See em_illness_death_phmm_weight. In each bootstrap, the propensity score model needs to be re-fitted, and fit the MSM illness-death general markov model with new IP weights.